require 'spec_helper'

describe Orgy::OrgObject do

  before(:each) do 
    @oo = Orgy::OrgObject.new
  end

  it "adds a child" do
    @oo.add_child(Orgy::OrgObject.new)
    @oo.children.length.should eql(1)
  end

  it "removes a child" do
    child = Orgy::OrgObject.new
    @oo.add_child(child)
    @oo.delete_child(child)
    @oo.children.length.should eql(0)
  end

  it "pushes a child" do
    child = Orgy::OrgObject.new
    @oo.push_child(child)
    @oo.children.length.should eql(1)
  end

  it "pops a child" do
    child = Orgy::OrgObject.new
    @oo.push_child(child)
    @oo.pop_child().should equal(child)
  end

  it "contains children" do
    child = Orgy::OrgObject.new
    @oo.push_child(child)
    @oo.contains_children?.should eql(true)
  end

  it "iterates through each child" do
    # Create Children
    child = Orgy::OrgObject.new
    child1 = Orgy::OrgObject.new
    child2 = Orgy::OrgObject.new

    # Add children
    @oo.add_child child
    @oo.add_child child1
    @oo.add_child child2

    x = 0
    @oo.each do | child |
      x = x + 1
    end
   
    x.should eql(3)
  end

  it "prints it's children to a string" do
    # Create Children
    child = Orgy::OrgObject.new
    child1 = Orgy::OrgObject.new

    @oo.push_child child
    @oo.push_child child1

    @oo.to_s.class.to_s.should eql 'String'
  end

  it "schedules an object" do
    @oo.schedule Orgy::OrgTimeStamp.new( DateTime.now )
    @oo.attribute[:scheduled].should_not eql nil
  end

  it "knows its scheduled" do
    @oo.schedule Orgy::OrgTimeStamp.new( DateTime.now )
    @oo.schedule?.should eql true
  end

  it "clears its schedule" do
    @oo.schedule Orgy::OrgTimeStamp.new( DateTime.now )
    @oo.clear_schedule
    @oo.schedule?.should eql false
  end

  it "sets a deadline" do
    @oo.deadline Orgy::OrgTimeStamp.new( DateTime.now )
    @oo.attribute[:deadline].should_not eql nil
  end

  it "knows it has a deadline" do
    @oo.deadline Orgy::OrgTimeStamp.new( DateTime.now )
    @oo.deadline?.should eql true
  end

  it "clears the deadline" do
    @oo.deadline Orgy::OrgTimeStamp.new( DateTime.now )
    @oo.clear_deadline
    @oo.deadline?.should_not eql true
  end

  it "prints object with schedule" do
    @oo.schedule Orgy::OrgTimeStamp.new ( DateTime.now )
    @oo.schedule?.should eql true
    #puts
    #puts @oo.to_s
    #puts
    expect {
      @oo.to_s =~ /SCHEDULE/
    }.should_not eql nil
  end
  
  it "prints object with schedule" do
    @oo.deadline Orgy::OrgTimeStamp.new ( DateTime.now )
    @oo.deadline?.should eql true
    #puts
    #puts @oo.to_s
    #puts
    expect {
      @oo.to_s =~ /DEADLINE/
    }.should_not eql nil
  end


  

end
